<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>@default</name>
    <message>
        <source>No sound file</source>
        <translation type="obsolete">未发现声音文件</translation>
    </message>
    <message>
        <source>You have to select a file to test the sound</source>
        <translation type="obsolete">必须选择一个声音文件</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation type="obsolete">确定(&amp;O)</translation>
    </message>
    <message>
        <source>No player</source>
        <translation type="obsolete">未发现播放器</translation>
    </message>
    <message>
        <source>You have to specify an external player</source>
        <translation type="obsolete">必须指定一个外部播放器</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermCanvas</name>
    <message>
        <source>zoom 1:1</source>
        <translation>缩放为 1:1</translation>
    </message>
    <message>
        <source>fit window</source>
        <translation type="obsolete">适应窗口</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <source>fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>rotate CW 90</source>
        <translation>顺时针旋转90度</translation>
    </message>
    <message>
        <source>rotate CCW 90</source>
        <translation>逆时针旋转90度</translation>
    </message>
    <message>
        <source>save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <source>copy to</source>
        <translation>复制到</translation>
    </message>
    <message>
        <source>silent copy</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>adjust size</source>
        <translation>调整尺寸</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Open Dir</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>show Fit</source>
        <translation>适合窗口</translation>
    </message>
    <message>
        <source>show MaxFit</source>
        <translation>适合窗口(拉伸)</translation>
    </message>
    <message>
        <source>show Origin</source>
        <translation>原始大小</translation>
    </message>
    <message>
        <source>show Stretch</source>
        <translation>拉伸</translation>
    </message>
    <message>
        <source>Adjust Mode</source>
        <translation>调整模式</translation>
    </message>
    <message>
        <source>No Preview Available</source>
        <translation>没有预览</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>保存文件失败</translation>
    </message>
    <message>
        <source>Cant save file, maybe format not supported</source>
        <translation>无法保存文件，可能为不支持的类型</translation>
    </message>
    <message>
        <source>play gif</source>
        <translation>播放gif</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermImage</name>
    <message>
        <source>Hide &amp;Browser</source>
        <translation type="obsolete">隐藏浏览器(&amp;B)</translation>
    </message>
    <message>
        <source>Show &amp;Browser</source>
        <translation type="obsolete">显示浏览器(&amp;B)</translation>
    </message>
    <message>
        <source>Hide &amp;List</source>
        <translation type="obsolete">隐藏列表(&amp;L)</translation>
    </message>
    <message>
        <source>Show &amp;List</source>
        <translation type="obsolete">显示列表(&amp;L)</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermImageFlow</name>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Trash All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Like </source>
        <translation>Like </translation>
    </message>
    <message>
        <source>New </source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Trash </source>
        <translation>Trash </translation>
    </message>
    <message>
        <source>Recover </source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Title </source>
        <translation>题目</translation>
    </message>
    <message>
        <source>Save your likes under</source>
        <translation></translation>
    </message>
    <message>
        <source>Recover</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermImageOrigin</name>
    <message>
        <source>FQTerm Image Viewer</source>
        <translation>FQTerm 图像浏览器</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>根据文件名排序</translation>
    </message>
    <message>
        <source>Sort by time</source>
        <translation>根据创建时间排序</translation>
    </message>
    <message>
        <source>Sort by size</source>
        <translation>根据文件大小排序</translation>
    </message>
    <message>
        <source>Sort by type</source>
        <translation>根据文件类型排序</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
    <message>
        <source>Comment : </source>
        <translation>评论:</translation>
    </message>
    <message>
        <source>Model</source>
        <translation>型号</translation>
    </message>
    <message>
        <source>ExposureTime</source>
        <translation>曝光时间</translation>
    </message>
    <message>
        <source>FNumber</source>
        <translation>F值</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>FocalLength</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>MeteringMode</source>
        <translation>测距模式</translation>
    </message>
    <message>
        <source>ExposureBias</source>
        <translation>曝光补偿</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermShortcutDialog</name>
    <message>
        <source>Shortcut Setting</source>
        <translation>快捷键设置</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>default</source>
        <translation>缺省</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Reset All</source>
        <translation>重置</translation>
    </message>
    <message>
        <source>Press key/combines on Shortcut column.
Note Del is reserved for clear shortcut setting.</source>
        <translation>在快捷键列按相应的自定义快捷键
按Del可以删除快捷键.</translation>
    </message>
</context>
<context>
    <name>FQTerm::ImageFlow</name>
    <message>
        <source>Tagged as </source>
        <translation>Tagged as </translation>
    </message>
</context>
<context>
    <name>FQTerm::ImageViewerDirModel</name>
    <message>
        <source>Image Preview</source>
        <translation>图像预览</translation>
    </message>
</context>
<context>
    <name>FQTerm::ProgressBar</name>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Aborted</source>
        <translation>中断</translation>
    </message>
    <message>
        <source>Aborting...</source>
        <translation>正在中断...</translation>
    </message>
</context>
<context>
    <name>FQTerm::StatusBar</name>
    <message>
        <source>Abort all background-operations</source>
        <translation>取消所有后台操作</translation>
    </message>
    <message>
        <source>Show progress detail</source>
        <translation>细节</translation>
    </message>
    <message>
        <source>Multiple background-tasks running</source>
        <translation>多任务后台运行中</translation>
    </message>
    <message>
        <source>Aborting all jobs...</source>
        <translation>取消所有任务...</translation>
    </message>
</context>
<context>
    <name>FQTerm::addrDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">确定</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="obsolete">设置</translation>
    </message>
    <message>
        <source>AddressBook</source>
        <translation type="obsolete">地址簿</translation>
    </message>
    <message>
        <source>Font Selector</source>
        <translation>选择文字</translation>
    </message>
</context>
<context>
    <name>FQTerm::quickDialog</name>
    <message>
        <source>Add To AddressBook</source>
        <translation>加入地址簿</translation>
    </message>
</context>
<context>
    <name>FQTerm::siteDialog</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The site configuration has been changed.
To save, press Yes.
To discard, press No.
To continue editing, press Cancel</source>
        <translation>站点设置已改变.
点击Yes保存设置
点击No保留原设置
继续编辑,点击Cancel</translation>
    </message>
    <message>
        <source>Are you sure to DELETE this site?</source>
        <translation>确认删除吗?</translation>
    </message>
</context>
<context>
    <name>FQTerm::soundConf</name>
    <message>
        <source>No such output driver</source>
        <translation type="obsolete">没有驱动</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">确认(&amp;O)</translation>
    </message>
    <message>
        <source>No sound file</source>
        <translation>未发现声音文件</translation>
    </message>
    <message>
        <source>You have to select a file to test the sound</source>
        <translation>必须选择一个声音文件</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>确定(&amp;O)</translation>
    </message>
    <message>
        <source>No player</source>
        <translation>未发现播放器</translation>
    </message>
    <message>
        <source>You have to specify an external player</source>
        <translation>必须指定一个外部播放器</translation>
    </message>
</context>
<context>
    <name>FQTermImage</name>
    <message>
        <source>Form1</source>
        <translation type="obsolete">窗体1</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">上一个(&amp;P)</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>&amp;Browser</source>
        <translation type="obsolete">浏览器(&amp;B)</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="obsolete">Alt+B</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">下一个(&amp;N)</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>ImageViewer</source>
        <translation type="obsolete">图像预览器</translation>
    </message>
    <message>
        <source>&amp;List</source>
        <translation type="obsolete">列表(&amp;L)</translation>
    </message>
</context>
<context>
    <name>IPLookupDialog</name>
    <message>
        <source>IP Lookup</source>
        <translation>查询IP</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP地址</translation>
    </message>
    <message>
        <source>Physical Address</source>
        <translation>实际地址</translation>
    </message>
    <message>
        <source>Lookup</source>
        <translation>查询</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>IP database file does NOT exist</source>
        <translation>IP数据库文件不存在</translation>
    </message>
    <message>
        <source>Invalid IP</source>
        <translation>非法IP</translation>
    </message>
</context>
<context>
    <name>SSHLogin</name>
    <message>
        <source>Login</source>
        <translation>登录</translation>
    </message>
    <message>
        <source>Please enter your username and password</source>
        <translation>请输入你的用户名和密码</translation>
    </message>
    <message>
        <source>UserName:</source>
        <translation>用户名:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>aboutDialog</name>
    <message>
        <source>About FQTerm</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>FQTerm 0.5.0 (QT 4.1 based)</source>
        <translation type="obsolete">FQTerm (基于QT4.1)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>FQTerm 2007</source>
        <translation type="obsolete">FQTerm 2007</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>致谢</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>FQTerm</source>
        <translation>FQTerm</translation>
    </message>
    <message>
        <source>FQTerm

http://code.google.com/p/fqterm</source>
        <translation type="obsolete">FQTerm

http://code.google.com/p/fqterm</translation>
    </message>
    <message>
        <source>fqterm@gmail.com

devilphoenix@newsmth</source>
        <translation>fqterm@gmail.com

devilphoenix@newsmth</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;SimSun&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;SimSun&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;FQTerm&lt;br /&gt;&lt;br /&gt;&lt;br /&gt;&lt;a href=&quot;http://code.google.com/p/fqterm&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://code.google.com/p/fqterm&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;FQTerm&lt;br /&gt;&lt;br /&gt;&lt;br /&gt;&lt;a href=&quot;http://code.google.com/p/fqterm&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://code.google.com/p/fqterm&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;SimSun&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;SimSun&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>addrDialog</name>
    <message>
        <source>AddressBook</source>
        <translation type="obsolete">地址簿</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">应用</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="obsolete">添加</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">关闭</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">删除</translation>
    </message>
    <message>
        <source>General</source>
        <translation>通用属性</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Auto Login</source>
        <translation type="obsolete">自动登录</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>BBS</source>
        <translation>BBS</translation>
    </message>
    <message>
        <source>*NIX</source>
        <translation>*NIX</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Prelogin</source>
        <translation>登录前</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Postlogin</source>
        <translation>登录后</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>ANSI Color</source>
        <translation>ANSI 颜色</translation>
    </message>
    <message>
        <source>Always Highlight</source>
        <translation>总是高亮</translation>
    </message>
    <message>
        <source>Auto Select Font Size When Resize Window</source>
        <translation type="obsolete">窗体变化时自动调整字体大小</translation>
    </message>
    <message>
        <source>BBS Encoding</source>
        <translation>BBS 编码</translation>
    </message>
    <message>
        <source>GBK</source>
        <translation>GBK</translation>
    </message>
    <message>
        <source>BIG5</source>
        <translation>BIG5</translation>
    </message>
    <message>
        <source>Display Code</source>
        <translation type="obsolete">显示编码</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>文字颜色</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <source>Schema</source>
        <translation type="obsolete">图表</translation>
    </message>
    <message>
        <source>TextLabel3</source>
        <translation>文本标签3</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>终端</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>列</translation>
    </message>
    <message>
        <source>Term Type</source>
        <translation>终端类型</translation>
    </message>
    <message>
        <source>Cursor Type</source>
        <translation>光标类型</translation>
    </message>
    <message>
        <source>Rows</source>
        <translation>行</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>块状</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>下划线</translation>
    </message>
    <message>
        <source>I Type</source>
        <translation>I形</translation>
    </message>
    <message>
        <source>Scroll Lines</source>
        <translation>滚动</translation>
    </message>
    <message>
        <source>Escape string (i.e. *[ )</source>
        <translation>ESC字符串(如*[)</translation>
    </message>
    <message>
        <source>Key Type</source>
        <translation>按键类型</translation>
    </message>
    <message>
        <source>VT100</source>
        <translation>VT100</translation>
    </message>
    <message>
        <source>XTERM</source>
        <translation>XTERM</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <source>Telnet</source>
        <translation>Telnet</translation>
    </message>
    <message>
        <source>SSH1</source>
        <translation>SSH1</translation>
    </message>
    <message>
        <source>SSH2</source>
        <translation>SSH2</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <source>Authentation</source>
        <translation>认证</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Wingate</source>
        <translation>Wingate</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>其它</translation>
    </message>
    <message>
        <source>Load Control Script</source>
        <translation>装载控制脚本</translation>
    </message>
    <message>
        <source>When disconnected, close window automatically</source>
        <translation>当连接断开时，自动关闭窗口</translation>
    </message>
    <message>
        <source>Autoreply Message</source>
        <translation>自动回复消息</translation>
    </message>
    <message>
        <source>Max Idle Time</source>
        <translation>最大发呆时间</translation>
    </message>
    <message>
        <source>Anti-idle String</source>
        <translation>防发呆字符串</translation>
    </message>
    <message>
        <source>For Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <source>Times (-1 means infinite)</source>
        <translation>次数(-1为无穷)</translation>
    </message>
    <message>
        <source>When disconnected, reconnect every</source>
        <translation>自动重连间隔</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
    <message>
        <source>Key to reply message</source>
        <translation>回复消息按键</translation>
    </message>
    <message>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <source>Menu Type</source>
        <translation>菜单类型</translation>
    </message>
    <message>
        <source>Menu Label</source>
        <translation type="obsolete">菜单标签</translation>
    </message>
    <message>
        <source>Reverse</source>
        <translation>反转</translation>
    </message>
    <message>
        <source>Color...</source>
        <translation>颜色...</translation>
    </message>
    <message>
        <source>Custom Color</source>
        <translation>自定义颜色</translation>
    </message>
    <message>
        <source>Site Setting</source>
        <translation>站点设置</translation>
    </message>
    <message>
        <source>Telnet Auto Login</source>
        <translation>Telnet自动登录</translation>
    </message>
    <message>
        <source>SSH Auto Login</source>
        <translation>SSH自动登录</translation>
    </message>
    <message>
        <source>Menu Color</source>
        <translation>菜单颜色</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">确认(&amp;O)</translation>
    </message>
    <message>
        <source>Apply (&amp;Temporarily)</source>
        <translation>应用 (临时&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Apply (Save)</source>
        <translation>应用 (保存&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>UTF8</source>
        <translation>UTF8</translation>
    </message>
    <message>
        <source>Font ratio</source>
        <translation type="obsolete">中英文比例</translation>
    </message>
    <message>
        <source>Adjust Font Size When Resize</source>
        <translation type="obsolete">自动调节字体</translation>
    </message>
    <message>
        <source>Char W/H ratio</source>
        <translation type="obsolete">字符高宽比(影响间距)</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <source>BackSpace Setting</source>
        <translation>退格键设定</translation>
    </message>
    <message>
        <source>Send backspace as ^H</source>
        <translation>退格键为^H</translation>
    </message>
    <message>
        <source>Send backspace as ^? (127)</source>
        <translation>退格键为^?(127)</translation>
    </message>
    <message>
        <source>Anti-idle</source>
        <translation>防发呆</translation>
    </message>
    <message>
        <source>Enable Zmodem</source>
        <translation>使用Zmodem</translation>
    </message>
    <message>
        <source>Enable Buzz</source>
        <translation>使用振动</translation>
    </message>
    <message>
        <source>Enable Beep</source>
        <translation>使用蜂鸣</translation>
    </message>
    <message>
        <source>Enable Mouse Support</source>
        <translation>打开鼠标支持</translation>
    </message>
    <message>
        <source>Align Mode</source>
        <translation>对齐模式</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>行间距</translation>
    </message>
    <message>
        <source>Char Spacing</source>
        <translation>字间距</translation>
    </message>
    <message>
        <source>Align Mid</source>
        <translation>中线对齐</translation>
    </message>
    <message>
        <source>Align Bottom</source>
        <translation>底部对齐</translation>
    </message>
    <message>
        <source>Align Top</source>
        <translation>顶端对齐</translation>
    </message>
    <message>
        <source>BIG5-HKSCS</source>
        <translation>BIG5-HKSCS</translation>
    </message>
    <message>
        <source>BIG5-UAO</source>
        <translation>BIG5-UAO</translation>
    </message>
    <message>
        <source>Keep Font; Adjust Row/Column.</source>
        <translation>保持字体大小,调整行列.</translation>
    </message>
    <message>
        <source>Keep Row/Column; Adjust Font.</source>
        <translation>保持行列,调整字体大小.</translation>
    </message>
    <message>
        <source>Keep Font; Keep Row/Column.</source>
        <translation>保持字体大小及行列.</translation>
    </message>
</context>
<context>
    <name>articleDialog</name>
    <message>
        <source>Article Viewer</source>
        <translation>文章浏览器</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Save...</source>
        <translation>保存...</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
</context>
<context>
    <name>dlgDefineEscape</name>
    <message>
        <source>Define Escape</source>
        <translation>定义逃逸</translation>
    </message>
    <message>
        <source>Escape String *[</source>
        <translation>逃逸串 *[</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>keyDialog</name>
    <message>
        <source>Key Setup</source>
        <translation>按键设置</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Define</source>
        <translation>定义</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>脚本</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>程序</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>回车</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>方向键[右]</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>方向键[左]</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>方向键[下]</translation>
    </message>
    <message>
        <source>General Keys</source>
        <translation>通用按键</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>方向键[上]</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>按键</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Short Cut</source>
        <translation>快捷键</translation>
    </message>
</context>
<context>
    <name>msgDialog</name>
    <message>
        <source>Messages Viewer</source>
        <translation>消息查看器</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
</context>
<context>
    <name>prefDialog</name>
    <message>
        <source>Preference</source>
        <translation>偏好</translation>
    </message>
    <message>
        <source>Alternative Mouse Wheel Control</source>
        <translation>其它滚动控制</translation>
    </message>
    <message>
        <source>Save Message To File</source>
        <translation>将消息储存至文件</translation>
    </message>
    <message>
        <source>Warn When Exit Connected</source>
        <translation>当连接时试图退出则发出警告</translation>
    </message>
    <message>
        <source>Detect URL When Mouse Move</source>
        <translation>鼠标移动时检测URL</translation>
    </message>
    <message>
        <source>Blink Tab When Receive Message</source>
        <translation>收到消息时闪烁</translation>
    </message>
    <message>
        <source>Paste word-wrap at</source>
        <translation type="obsolete">自动回行粘贴</translation>
    </message>
    <message>
        <source>Sound When Receive Messages</source>
        <translation>收到消息时发声</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Beep</source>
        <translation>蜂鸣</translation>
    </message>
    <message>
        <source>Sound File</source>
        <translation>声音文件</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Enable Smart Word-Wrap</source>
        <translation>智能自动回行</translation>
    </message>
    <message>
        <source>Clear ZModem and HTTP directory when exit</source>
        <translation type="obsolete">退出时清理ZModem和HTTP目录</translation>
    </message>
    <message>
        <source>Show as tray when close</source>
        <translation type="obsolete">关闭至系统托盘</translation>
    </message>
    <message>
        <source>Zmodem directory</source>
        <translation type="obsolete">Zmodem目录</translation>
    </message>
    <message>
        <source>HTTP directory</source>
        <translation type="obsolete">HTTP目录</translation>
    </message>
    <message>
        <source>HTTP Browser</source>
        <translation>HTTP浏览器</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation>图像预览器</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Input Method</source>
        <translation>输入法</translation>
    </message>
    <message>
        <source>GBK</source>
        <translation>GBK</translation>
    </message>
    <message>
        <source>BIG5</source>
        <translation>BIG5</translation>
    </message>
    <message>
        <source>Paste Word-Wrap At</source>
        <translation>自动回行粘贴</translation>
    </message>
    <message>
        <source>Show As Tray When Close</source>
        <translation>关闭至系统托盘</translation>
    </message>
    <message>
        <source>Clear ZModem And HTTP Directory When Exit</source>
        <translation>退出时清理ZModem和HTTP目录</translation>
    </message>
    <message>
        <source>Zmodem Directory</source>
        <translation>Zmodem目录</translation>
    </message>
    <message>
        <source>HTTP Directory</source>
        <translation>HTTP目录</translation>
    </message>
    <message>
        <source>StyleSheet File</source>
        <translation>StyleSheet文件</translation>
    </message>
    <message>
        <source>Reply when ENQ received</source>
        <translation>收到ENQ时回复</translation>
    </message>
    <message>
        <source>Display Offset</source>
        <translation>显示(横向)偏移量</translation>
    </message>
    <message>
        <source>Editor &amp; Args</source>
        <translation>编辑器及运行参数</translation>
    </message>
    <message>
        <source>AntiAlias</source>
        <translation>反别名</translation>
    </message>
    <message>
        <source>Vertical Display</source>
        <translation>垂直显示</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>居顶</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation>居中</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>居底</translation>
    </message>
    <message>
        <source>ASCII Art Enhance Mode</source>
        <translation>ASCII色块无缝模式</translation>
    </message>
</context>
<context>
    <name>quickDialog</name>
    <message>
        <source>Quick Login</source>
        <translation>快速连接</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="obsolete">历史</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">地址</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <source>Telnet</source>
        <translation>Telnet</translation>
    </message>
    <message>
        <source>SSH1</source>
        <translation>SSH1</translation>
    </message>
    <message>
        <source>SSH2</source>
        <translation>SSH2</translation>
    </message>
    <message>
        <source>Host Name</source>
        <translation>主机名</translation>
    </message>
    <message>
        <source>23</source>
        <translation>23</translation>
    </message>
</context>
<context>
    <name>schemaDialog</name>
    <message>
        <source>Schema Editor</source>
        <translation>图标编辑器</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>8-15</source>
        <translation>8-15</translation>
    </message>
    <message>
        <source>0-7</source>
        <translation>0-7</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Remove </source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <source>Fade to</source>
        <translation type="obsolete">淡入</translation>
    </message>
    <message>
        <source>Min</source>
        <translation>最小</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>平铺</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>比例</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>图像</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation type="obsolete">透明</translation>
    </message>
    <message>
        <source>Render</source>
        <translation>渲染</translation>
    </message>
    <message>
        <source>Coverage</source>
        <translation>覆盖范围</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation>整体</translation>
    </message>
    <message>
        <source>Padding</source>
        <translation>平直</translation>
    </message>
    <message>
        <source>Note:
 Alpha will only apply on background
 If Coverage is set to Padding
 Alpha will take no effect
</source>
        <translation>请注意：
 Alpha仅应用于背景色
 若“覆盖范围”被设置为“平直”
 Alpha将不会生效
</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>半透明</translation>
    </message>
</context>
<context>
    <name>siteManager</name>
    <message>
        <source>Address Book</source>
        <translation>地址簿</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>上移(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>下移(&amp;D)</translation>
    </message>
    <message>
        <source>Site Name</source>
        <translation>站点名称</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <source>Telnet</source>
        <translation>Telnet</translation>
    </message>
    <message>
        <source>SSH1</source>
        <translation>SSH1</translation>
    </message>
    <message>
        <source>SSH2</source>
        <translation>SSH2</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Host Type</source>
        <translation>主机类型</translation>
    </message>
    <message>
        <source>BBS</source>
        <translation>BBS</translation>
    </message>
    <message>
        <source>*NIX</source>
        <translation>*NIX</translation>
    </message>
    <message>
        <source>Use Proxy</source>
        <translation>使用代理</translation>
    </message>
    <message>
        <source>Setting...</source>
        <translation>设置...</translation>
    </message>
    <message>
        <source>Auto Login</source>
        <translation>自动登录</translation>
    </message>
    <message>
        <source>Font Preview</source>
        <translation>字体预览</translation>
    </message>
    <message>
        <source>Font Previewer</source>
        <translation>字体预览</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation>重置(&amp;R)</translation>
    </message>
    <message>
        <source>A&amp;dvance</source>
        <translation>高级(&amp;d)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>C&amp;onnect</source>
        <translation>连接(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation type="obsolete">应用(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
</context>
<context>
    <name>soundConf</name>
    <message>
        <source>Configure</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Sound File:</source>
        <translation>声音文件:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>External Program:</source>
        <translation>外部程序:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Play With:</source>
        <translation>使用播放器:</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>测试</translation>
    </message>
    <message>
        <source>External</source>
        <translation>外部</translation>
    </message>
    <message>
        <source>Internal</source>
        <translation>内部</translation>
    </message>
</context>
<context>
    <name>zmodemDialog</name>
    <message>
        <source>Zmodem Status</source>
        <translation>Zmodem状态</translation>
    </message>
    <message>
        <source>textLabel1</source>
        <translation>文本标签1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>textLabel2</source>
        <translation>文本标签2</translation>
    </message>
</context>
</TS>
